rpms/bubbros/devel bubbros-1.5-fixes.patch, NONE, 1.1 bubbros.desktop, NONE, 1.1 bubbros.spec, NONE, 1.1 .cvsignore, 1.1, 1.2 sources, 1.1, 1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/bubbros/devel
In directory se02.es.rpmfusion.net:/tmp/cvs-serv6474/devel
Modified Files:
.cvsignore sources
Added Files:
bubbros-1.5-fixes.patch bubbros.desktop bubbros.spec
Log Message:
initial bubbros import
bubbros-1.5-fixes.patch:
--- NEW FILE bubbros-1.5-fixes.patch ---
--- bubbros-1.5/http2/httppages.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/http2/httppages.py 2006-07-28 22:22:51.000000000 +0200
@@ -38,7 +38,8 @@
class PageServer:
- CONFIGFILE = 'config.txt'
+ CONFIGFILE = os.path.join(os.environ.get('HOME', '.'), '.bubbros',
+ 'config.txt')
localservers = None
def __init__(self, Game):
--- bubbros-1.5/BubBob.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/BubBob.py 2006-07-28 22:22:51.000000000 +0200
@@ -26,16 +26,11 @@
sys.path.append(LOCALDIR)
os.chdir(LOCALDIR)
-try:
- username = '-'+os.getlogin()
-except:
- try:
- import pwd
- username = '-'+pwd.getpwuid(os.getuid())[0]
- except:
- username = ''
-TAGFILENAME = 'BubBob-%s%s.url' % (socket.gethostname(), username)
-TAGFILENAME = os.path.join(tempfile.gettempdir(), TAGFILENAME)
+rcdir = os.path.join(os.environ.get("HOME", "."), ".bubbros")
+if not os.path.isdir(rcdir):
+ os.makedirs(rcdir)
+TAGFILENAME = 'BubBob-%s.url' % (socket.gethostname())
+TAGFILENAME = os.path.join(rcdir, TAGFILENAME)
def load_url_file():
@@ -129,7 +129,7 @@
browser = webbrowser.get()
name = getattr(browser, 'name', browser.__class__.__name__)
print "Trying to open '%s' with '%s'..." % (url, name)
- browser.open(url)
+ webbrowser.open(url)
except:
exc, val, tb = sys.exc_info()
print '-'*60
--- bubbros-1.5/bubbob/bonuses.py.fixes 2006-02-04 19:56:12.000000000 +0100
+++ bubbros-1.5/bubbob/bonuses.py 2006-07-28 22:22:51.000000000 +0200
@@ -1387,6 +1387,10 @@
try:
+ if sys.path[1][0:10] == '/usr/lib64':
+ sys.path.append('/usr/lib64/bubbros')
+ else:
+ sys.path.append('/usr/lib/bubbros')
import statesaver
except ImportError:
print "'statesaver' module not compiled, no clock bonus"
--- bubbros-1.5/bubbob/bb.py.fixes 2006-02-04 19:56:12.000000000 +0100
+++ bubbros-1.5/bubbob/bb.py 2006-07-28 22:22:51.000000000 +0200
@@ -14,6 +14,10 @@
pass
LOCALDIR = os.path.dirname(os.path.abspath(LOCALDIR))
# ----------
+rcdir = os.path.join(os.environ.get("HOME", "."), ".bubbros")
+if not os.path.isdir(rcdir):
+ os.makedirs(rcdir)
+# ----------
import random, time
--- bubbros-1.5/doc/Client.py.1.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/doc/Client.py.1 2006-07-28 22:22:51.000000000 +0200
@@ -1,27 +1,23 @@
-.\" $Id: Client.py.1,v 1.3 2005/05/06 21:32:38 arigo Exp $
+.\" $Id: bubbros-client.6,v 1.3 2005/05/06 21:32:38 arigo Exp $
.\"
.\" Process this file with
-.\" groff -man -Tascii Client.py.1
+.\" groff -man -Tascii bubbros-client.6
.\"
-.TH Client.py 1 "APRIL 2005" Linux "User Manuals"
+.TH bubbros-client 6 "APRIL 2005" Linux "User Manuals"
.SH NAME
-Client.py \- the bub-n-bros client
+bubbros-client \- the bub-n-bros client
.SH SYNOPSIS
-.B python Client.py [
+.B bubbros-client [
.I options
.BI "] [" host [: port ]]
-.PP
-Note that this script is in the
-.B display/
-subdirectory of the original directory layout.
.SH DESCRIPTION
This is the bub-n-bros client that connects to bub-n-bros servers
started with
-.BR bb.py "(1) or " BubBob.py (1) .
+.BR bubbros-server "(6) or " bubbros (6) .
It supports many different audio and video drivers and is very
multi-platform.
@@ -38,12 +34,6 @@
defined, search for servers on the local network.
.TP
-.BI --bits= N
-This option concerns only the
-.B windows
-audio driver. Set bits per sample. Valid values are 8 and 16 (default).
-
-.TP
.BI "-d " DRIVER ", --display=" DRIVER
Use video driver
.IR DRIVER .
@@ -57,9 +47,6 @@
.B --shm
option.
.TP
-.B windows
-MS Windows driver.
-.TP
.B pygame
PyGame gaming library for python (if installed) has video output. Use
it if this is specified. See
@@ -86,21 +73,21 @@
.TP
.BI --freq= N
This option concerns only the
-.BR linux " and " windows
-audio drivers. Set mixing frequency to
+.BR linux
+audio driver. Set mixing frequency to
.I N
(in Hz). Defaults to 44100.
.TP
.B -m, --metaserver
Connect with the help of the Metaserver (see
-.BR bb.py (1)
+.BR bubbros-server (6)
for more info). Run
-.I Client.py -m
+.I bubbros-client -m
to print a table of currently running servers, pick the
the exact IP address and port of the server of your choice
from the table, and run again
-.I Client.py -m
+.I bubbros-client -m
.BR host:port .
.TP
@@ -145,11 +132,6 @@
.BR --freq " and " --fmt " options."
.TP
-.B windows
-Use the Windows audio mixer. See the
-.BR --freq " and " --bits "options."
-
-.TP
.B off
No sounds.
.RE
@@ -195,6 +177,6 @@
.IR N %.
.SH SEE ALSO
-.BR bb.py (1)
-.BR Client.py (1)
+.BR bubbros (6)
+.BR bubbros-server (6)
.BR python (1)
\ No newline at end of file
--- bubbros-1.5/doc/BubBob.py.1.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/doc/BubBob.py.1 2006-07-28 22:22:51.000000000 +0200
@@ -1,23 +1,21 @@
-.\" $Id: BubBob.py.1,v 1.2 2005/04/13 18:24:17 opqdonut Exp $
+.\" $Id: bubbros.6,v 1.2 2005/04/13 18:24:17 opqdonut Exp $
.\"
.\" Process this file with
-.\" groff -man -Tascii BubBob.py.1
+.\" groff -man -Tascii bubbros.6
.\"
-.TH BubBob.py 1 "APRIL 2005" Linux "User Manuals"
+.TH bubbros 6 "APRIL 2005" Linux "User Manuals"
.SH NAME
-BubBob.py \- Generic startup script for bub-n-bros
+bubbros \- Generic startup script for bub-n-bros
.SH SYNOPSIS
-.B BubBob.py
-.br
-.B python BubBob.py
+.B bubbros
.SH DESCRIPTION
-.B BubBob.py
+.B bubbros
runs
-.BR bb.py (1)
+.BR bubbros-server (6)
(the bub-n-bros server) and then tries to open the url of its control
panel in your webbrowser.
@@ -26,7 +24,7 @@
on Unix systems.
.SH SEE ALSO
-.BR bb.py (1)
-.BR Client.py (1)
+.BR bubbros-server (6)
+.BR bubbros-client (6)
.BR python (1)
--- bubbros-1.5/doc/bb.py.1.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/doc/bb.py.1 2006-07-28 22:22:51.000000000 +0200
@@ -1,29 +1,21 @@
-.\" $Id: bb.py.1,v 1.3 2005/04/17 17:19:32 opqdonut Exp $
+.\" $Id: bubbros-server.6,v 1.3 2005/04/17 17:19:32 opqdonut Exp $
.\"
.\" Process this file with
-.\" groff -man -Tascii bb.py.1
+.\" groff -man -Tascii bubbros-server.6
.\"
-.TH bb.py 1 "APRIL 2005" Linux "User Manuals"
+.TH bubbros-server 6 "APRIL 2005" Linux "User Manuals"
.SH NAME
-bb.py \- the bub-n-bros server.
+bubbros-server \- the bub-n-bros server.
.SH SYNOPSIS
-.B bb.py [
+.B bubbros-server [
.I level-file.bin
.BI "] [" options ]
-.br
-.B python bb.py [
-.I level-file.bin
-.BI "] [" options ]
-.PP
-Note that this script is in the
-.B bubbob/
-subdirectory of the original directory layout.
.SH DESCRIPTION
-.B bb.py
+.B bubbros-server
starts an http server that acts as a control panel for the server. The
server listens on port
.B 8000
@@ -124,6 +116,6 @@
game servers.
.SH SEE ALSO
-.BR BubBob.py (1)
-.BR Client.py (1)
+.BR bubbros (6)
+.BR bubbros-client (6)
.BR python (1)
--- bubbros-1.5/display/modes.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/display/modes.py 2006-07-28 22:22:51.000000000 +0200
@@ -29,6 +29,10 @@
self.extraoptsdescr = extraoptsdescr
self.options = options.copy()
self.url = url
+ if sys.path[1][0:10] == '/usr/lib64':
+ sys.path.append('/usr/lib64/bubbros')
+ else:
+ sys.path.append('/usr/lib/bubbros')
def getmodule(self):
return __import__(self.prefix + self.name.lower(), globals(),
@@ -94,18 +98,18 @@
def graphicmodeslist():
return [
+ GraphicMode('pygame', 'PyGame library (all platforms)',
+ ['--fullscreen=yes go full screen (Esc key to exit, default)',
+ '--fullscreen=no run in windowed mode',
+ '--transparency=yes slightly transparent bubbles (default)',
+ '--transparency=no disable it (a bit faster)'],
+ {'transparency': 'yes', 'fullscreen': 'yes'},
+ url='http://www.pygame.org'),
GraphicMode('X', 'XWindow (Linux/Unix)',
['--shm=yes use the Shared Memory extension (default)',
'--shm=no disable it (for remote connections or old X servers)',
],
{'shm': 'yes'}),
- GraphicMode('windows', 'MS Windows', []),
- GraphicMode('pygame', 'PyGame library (all platforms)',
- ['--fullscreen=yes go full screen (Esc key to exit)',
- '--transparency=yes slightly transparent bubbles (default)',
- '--transparency=no disable it (a bit faster)'],
- {'transparency': 'yes', 'fullscreen': 'no'},
- url='http://www.pygame.org'),
GraphicMode('gtk', 'PyGTK (Gnome)',
['--zoom=xxx% scale image by xxx %'],
{'zoom': '100'},
@@ -120,10 +124,6 @@
['--freq=# mixer frequency (default 44100)',
'--fmt=# data format (default S16_NE, --fmt=list for a list)'],
{'freq': '44100', 'fmt': 'S16_NE'}),
- SoundMode('windows', 'audio mixer for Windows',
- ['--freq=# mixer frequency (default 44100)',
- '--bits=# bits per sample (8 or default 16)'],
- {'freq': '44100', 'bits': '16'}),
SoundMode('off', 'no sounds', []),
]
--- bubbros-1.5/display/dpy_pygame.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/display/dpy_pygame.py 2006-07-28 22:23:54.000000000 +0200
@@ -13,7 +13,7 @@
musthidemouse = 0
mousevisible = 1
- def __init__(self, width, height, title, transparency='yes', fullscreen='no'):
+ def __init__(self, width, height, title, transparency='yes', fullscreen='yes'):
self.use_transparency = not transparency.startswith('n')
self.use_fullscreen = fullscreen.startswith('y')
@@ -200,7 +200,7 @@
return '''
<%s> Full Screen (Esc key to exit)</input><%s><br>
<%s> Draw slightly transparent bubbles</input><%s><br>
-''' % (nameval("checkbox", "fullscreen", "yes", default="no"),
+''' % (nameval("checkbox", "fullscreen", "yes", default="yes"),
nameval("hidden", "fullscreen", "no"),
nameval("checkbox", "transparency", "yes", default="yes"),
nameval("hidden", "transparency", "no"))
--- bubbros-1.5/display/pclient.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/display/pclient.py 2006-07-28 22:22:51.000000000 +0200
@@ -155,8 +155,8 @@
if mode[-1].has_key('cfgfile'):
self.trackcfgfile = mode[-1]['cfgfile']
else:
- self.trackcfgfile = os.path.join(DataChunk.SOURCEDIR,
- 'http2', 'config.txt')
+ self.trackcfgfile = os.path.join(os.environ.get('HOME', '.'),
+ '.bubbros', 'config.txt')
self.udpsock = None
self.udpsock_low = None
self.udpsock2 = None
--- bubbros-1.5/common/stdlog.py.fixes 2006-02-04 19:56:31.000000000 +0100
+++ bubbros-1.5/common/stdlog.py 2006-07-28 22:22:51.000000000 +0200
@@ -6,7 +6,8 @@
def __init__(self, filename=None, limitsize=32768):
if filename is None:
- filename = sys.argv[0]
+ filename = os.path.join(os.environ.get('HOME', '.'), '.bubbros',
+ os.path.basename(sys.argv[0]))
if filename.endswith('.py'):
filename = filename[:-3]
filename += '.log'
diff -up bubbros-1.6/bubbob/statesaver.c~ bubbros-1.6/bubbob/statesaver.c
--- bubbros-1.6/bubbob/statesaver.c~ 2007-09-10 11:50:46.000000000 +0200
+++ bubbros-1.6/bubbob/statesaver.c 2007-09-10 11:50:46.000000000 +0200
@@ -75,10 +75,6 @@ static PyObject* genbuild(PyObject* g)
Py_INCREF(g); /* exhausted -- can return 'g' itself */
return g;
}
- if (f->f_nfreevars || f->f_ncells) {
- PyErr_SetString(PyExc_ValueError, "generator has cell or free vars");
- goto error;
- }
if (co->co_argcount == 0)
dummy = NULL;
@@ -143,11 +139,6 @@ static int gencopy(PyObject* g2, PyObjec
}
f2 = (PyFrameObject*) x;
- if (f2->f_stacksize != f->f_stacksize) {
- PyErr_SetString(PyExc_TypeError, "stack size mismatch");
- goto error;
- }
-
if (f2->f_stacktop != NULL)
while (f2->f_stacktop != f2->f_localsplus)
{
diff -up bubbros-1.6/java/Makefile~ bubbros-1.6/java/Makefile
--- bubbros-1.6/java/Makefile~ 2007-09-10 11:53:35.000000000 +0200
+++ bubbros-1.6/java/Makefile 2007-09-10 11:53:35.000000000 +0200
@@ -1,2 +1,2 @@
pclient.class: pclient.java
- javac -target 1.1 pclient.java
+ javac -target 1.1 -source 1.3 pclient.java
--- NEW FILE bubbros.desktop ---
[Desktop Entry]
Encoding=UTF-8
Name=BubBros
Comment=Bub and Brothers game inspired by the classic Bubble and Bobble
Exec=bubbros
Icon=bubbros
Terminal=false
StartupNotify=false
Type=Application
Categories=Game;ArcadeGame;
--- NEW FILE bubbros.spec ---
Name: bubbros
Version: 1.6
Release: 1%{?dist}
Summary: Bub and Brothers game inspired by the classic Bubble and Bobble
Group: Amusements/Games
License: MIT and Artistic Licenses
URL: http://bub-n-bros.sourceforge.net/
Source0: http://downloads.sourceforge.net/bub-n-bros/%{name}-%{version}.tar.bz2
Source1: bubbros.desktop
Patch0: bubbros-1.5-fixes.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: python-devel ImageMagick desktop-file-utils libX11-devel
BuildRequires: libXext-devel xorg-x11-proto-devel java-1.4.2-gcj-compat-devel
Requires: python-abi = %(%{__python} -c "import sys ; print sys.version[:3]")
Requires: pygame pygtk2 htmlview hicolor-icon-theme
%description
This is a direct clone of the MacOS game Bub & Bob of McSebi. Thanks Sebi for
all the cool graphics and sounds!
Features:
* 1 to 10 players -- the best fun is with at least 3 players!
* Same gameplay as the famous McSebi's Bub & Bob.
* Over-the-network game and/or up to 3 players on the same computer.
* Completely original crazy bonuses!
* Capture other players in a bubble!
* New levels, including a random level generator!
%prep
%setup -q
#no backups for this patch, otherwise they end up getting installed!
%patch0 -p1
sed -i 's:#! /usr/bin/env python:#!%{__python}:' BubBob.py bubbob/bb.py \
display/Client.py
chmod +x display/Client.py
# for %doc
mv bubbob/levels/README.txt levels.txt
%build
make %{?_smp_mflags}
pushd bubbob/images
python buildcolors.py
popd
pushd java
rm *.class
make
popd
convert bubbob/images/dragon_0.ppm -transparent '#010101' -crop 32x32+0+0 \
%{name}.png
%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man6
# copying the complete dirs and then removing the unwanted bits is easier :)
cp -a BubBob.py bubbob common display http2 java metaserver \
$RPM_BUILD_ROOT%{_datadir}/%{name}
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}/bubbob/build
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}/bubbob/doc
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}/display/build
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}/display/windows
rm $RPM_BUILD_ROOT%{_datadir}/%{name}/display/*_windows.py
rm -fr $RPM_BUILD_ROOT%{_datadir}/%{name}/http2/sf
rm $RPM_BUILD_ROOT%{_datadir}/%{name}/http2/header.png
rm $RPM_BUILD_ROOT%{_datadir}/%{name}/java/pclient.java
rm `find $RPM_BUILD_ROOT%{_datadir}/%{name} -name '*.c'`
rm `find $RPM_BUILD_ROOT%{_datadir}/%{name} -name 'Makefile'`
rm `find $RPM_BUILD_ROOT%{_datadir}/%{name} -name 'setup.py'`
# put the .so files in %{libdir}
mv `find $RPM_BUILD_ROOT%{_datadir}/%{name} -name '*.so'` \
$RPM_BUILD_ROOT%{_libdir}/%{name}
# create the symlinks in /usr/bin, these must be absolute links!
ln -s %{_datadir}/%{name}/BubBob.py $RPM_BUILD_ROOT%{_bindir}/bubbros
ln -s %{_datadir}/%{name}/bubbob/bb.py $RPM_BUILD_ROOT%{_bindir}/bubbros-server
ln -s %{_datadir}/%{name}/display/Client.py \
$RPM_BUILD_ROOT%{_bindir}/bubbros-client
# install the manpages
install -m 644 doc/BubBob.py.1 $RPM_BUILD_ROOT%{_mandir}/man6/bubbros.6
install -m 644 doc/bb.py.1 $RPM_BUILD_ROOT%{_mandir}/man6/bubbros-server.6
install -m 644 doc/Client.py.1 $RPM_BUILD_ROOT%{_mandir}/man6/bubbros-client.6
# below is the desktop file and icon stuff.
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
desktop-file-install --vendor dribble \
--dir $RPM_BUILD_ROOT%{_datadir}/applications \
%{SOURCE1}
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/32x32/apps
install -p -m 644 %{name}.png \
$RPM_BUILD_ROOT%{_datadir}/icons/hicolor/32x32/apps
%clean
rm -rf $RPM_BUILD_ROOT
%post
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
%postun
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
%{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi
%files
%defattr(-,root,root,-)
%doc LICENSE.txt artistic.txt levels.txt
%{_bindir}/bubbros*
%{_libdir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/dribble-%{name}.desktop
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_mandir}/man6/bubbros*.6.gz
%changelog
* Mon Sep 10 2007 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.6-1
- New upstream release 1.6
* Mon Jan 15 2007 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.5-3
- Rebuild (with compile and run fixes) for new python2.5
* Tue Aug 1 2006 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.5-2
- Add missing BuildRequires: libX11-devel libXext-devel xorg-x11-proto-devel
- Add Requires: htmlview
- Recompile java code instead of using precompiled .class files
- Don't install java source code, only class files
* Fri Jul 28 2006 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.5-1
- initial Dribble package
Index: .cvsignore
===================================================================
RCS file: /cvs/free/rpms/bubbros/devel/.cvsignore,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- .cvsignore 31 May 2008 14:07:17 -0000 1.1
+++ .cvsignore 24 Jul 2008 11:29:04 -0000 1.2
@@ -0,0 +1 @@
+bubbros-1.6.tar.bz2
Index: sources
===================================================================
RCS file: /cvs/free/rpms/bubbros/devel/sources,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- sources 31 May 2008 14:07:17 -0000 1.1
+++ sources 24 Jul 2008 11:29:04 -0000 1.2
@@ -0,0 +1 @@
+00aa5e26f5f0ed4c10765e4b33b28a09 bubbros-1.6.tar.bz2
16 years, 7 months
rpms/lha/F-8 lha-1.14i-dir_length_bounds_check.patch, NONE, 1.1 lha-1.14i-malloc.patch, NONE, 1.1 lha-1.14i-sec.patch, NONE, 1.1 lha-1.14i-sec2.patch, NONE, 1.1 lha-1.14i-symlink.patch, NONE, 1.1 lha.spec, NONE, 1.1
by jwrdegoede
Author: jwrdegoede
Update of /cvs/nonfree/rpms/lha/F-8
In directory se02.es.rpmfusion.net:/tmp/cvs-serv5684
Added Files:
lha-1.14i-dir_length_bounds_check.patch lha-1.14i-malloc.patch
lha-1.14i-sec.patch lha-1.14i-sec2.patch
lha-1.14i-symlink.patch lha.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
- Release bump for rpmfusion build
lha-1.14i-dir_length_bounds_check.patch:
--- NEW FILE lha-1.14i-dir_length_bounds_check.patch ---
--- lha-114i.orig/src/header.c 2002-07-19 17:23:58.000000000 +0900
+++ lha-114i/src/header.c 2004-06-16 09:49:23.000000000 +0900
@@ -648,8 +648,17 @@
}
if (dir_length) {
+ if ((dir_length + name_length) > sizeof(dirname)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
strcat(dirname, hdr->name);
- strcpy(hdr->name, dirname);
+
+ if ((dir_length + name_length) > sizeof(hdr->name)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
+ strncpy(hdr->name, dirname, sizeof(hdr->name));
name_length += dir_length;
}
lha-1.14i-malloc.patch:
--- NEW FILE lha-1.14i-malloc.patch ---
--- lha-114i/src/lha.h.orig 2004-05-19 19:24:19.000000000 -0400
+++ lha-114i/src/lha.h 2004-05-19 19:23:19.000000000 -0400
@@ -16,6 +16,7 @@
#include <sys/types.h>
#include <sys/file.h>
#include <sys/stat.h>
+#include <malloc.h>
#include <signal.h>
lha-1.14i-sec.patch:
--- NEW FILE lha-1.14i-sec.patch ---
--- lha-114i/src/header.c.orig 2000-10-05 19:36:03.000000000 +0200
+++ lha-114i/src/header.c 2004-04-21 14:30:52.000000000 +0200
@@ -538,6 +538,10 @@
/*
* filename
*/
+ if (header_size >= 256) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #1\n");
+ exit(109);
+ }
for (i = 0; i < header_size - 3; i++)
hdr->name[i] = (char) get_byte();
hdr->name[header_size - 3] = '\0';
@@ -547,6 +551,10 @@
/*
* directory
*/
+ if (header_size >= FILENAME_LENGTH) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #2\n");
+ exit(110);
+ }
for (i = 0; i < header_size - 3; i++)
dirname[i] = (char) get_byte();
dirname[header_size - 3] = '\0';
--- lha-114i/src/lhext.c.orig 2000-10-04 16:57:38.000000000 +0200
+++ lha-114i/src/lhext.c 2004-04-21 14:30:52.000000000 +0200
@@ -190,8 +190,13 @@
q = (char *) rindex(hdr->name, '/') + 1;
}
else {
+ if (is_directory_traversal(q)) {
+ fprintf(stderr, "Possible directory traversal hack attempt in %s\n", q);
+ exit(111);
+ }
+
if (*q == '/') {
- q++;
+ while (*q == '/') { q++; }
/*
* if OSK then strip device name
*/
@@ -419,6 +424,33 @@
return;
}
+int
+is_directory_traversal(char *string)
+{
+ unsigned int type = 0; /* 0 = new, 1 = only dots, 2 = other chars than dots */
+ char *temp;
+
+ temp = string;
+
+ while (*temp != 0) {
+ if (temp[0] == '/') {
+ if (type == 1) { return 1; }
+ type = 0;
+ temp++;
+ continue;
+ }
+
+ if ((temp[0] == '.') && (type < 2))
+ type = 1;
+ if (temp[0] != '.')
+ type = 2;
+
+ temp++;
+ } /* while */
+
+ return (type == 1);
+}
+
/* Local Variables: */
/* mode:c */
/* tab-width:4 */
lha-1.14i-sec2.patch:
--- NEW FILE lha-1.14i-sec2.patch ---
diff -urNp lha-114i.orig/src/lha_macro.h lha-114i/src/lha_macro.h
--- lha-114i.orig/src/lha_macro.h 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lha_macro.h 2004-08-03 15:54:05.000000000 -0500
@@ -53,7 +53,7 @@
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
-#endif /* SEEK_SET
+#endif /* SEEK_SET */
/* non-integral functions */
diff -urNp lha-114i.orig/src/lharc.c lha-114i/src/lharc.c
--- lha-114i.orig/src/lharc.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lharc.c 2004-08-03 15:54:05.000000000 -0500
@@ -830,9 +830,10 @@ find_files(name, v_filec, v_filev)
DIRENTRY *dp;
struct stat tmp_stbuf, arc_stbuf, fil_stbuf;
- strcpy(newname, name);
+ strncpy(newname, name, sizeof(newname));
+ newname[sizeof(newname)-1] = 0;
len = strlen(name);
- if (len > 0 && newname[len - 1] != '/')
+ if (len > 0 && newname[len - 1] != '/' && len < (sizeof(newname)-1))
newname[len++] = '/';
dirp = opendir(name);
@@ -846,6 +847,11 @@ find_files(name, v_filec, v_filev)
for (dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
n = NAMLEN(dp);
+ if (len >= (sizeof(newname)-1) ||
+ (len+n) >= (sizeof(newname)-1) ||
+ n <= 0 ||
+ (len+n) <= 0)
+ break;
strncpy(newname + len, dp->d_name, n);
newname[len + n] = '\0';
if (GETSTAT(newname, &fil_stbuf) < 0)
@@ -903,7 +909,8 @@ build_temporary_name()
strcpy(temporary_name, TMP_FILENAME_TEMPLATE);
}
else {
- sprintf(temporary_name, "%s/lhXXXXXX", extract_directory);
+ snprintf(temporary_name, sizeof(temporary_name),
+ "%s/lhXXXXXX", extract_directory);
}
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -913,10 +920,16 @@ build_temporary_name()
#else
char *p, *s;
- strcpy(temporary_name, archive_name);
+ strncpy(temporary_name, archive_name, sizeof(temporary_name));
+ temporary_name[sizeof(temporary_name)-1] = 0;
for (p = temporary_name, s = (char *) 0; *p; p++)
if (*p == '/')
s = p;
+
+ if( sizeof(temporary_name) - ((size_t) (s-temporary_name)) - 1
+ <= strlen("lhXXXXXX"))
+ exit(-1);
+
strcpy((s ? s + 1 : temporary_name), "lhXXXXXX");
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -1052,7 +1065,8 @@ open_old_archive()
if (open_old_archive_1(archive_name, &fp))
return fp;
- sprintf(expanded_archive_name, "%s.lzh", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzh", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
@@ -1061,7 +1075,8 @@ open_old_archive()
* if ( (errno&0xffff)!=E_PNNF ) { archive_name =
* expanded_archive_name; return NULL; }
*/
- sprintf(expanded_archive_name, "%s.lzs", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzs", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
diff -urNp lha-114i.orig/src/lhext.c lha-114i/src/lhext.c
--- lha-114i.orig/src/lhext.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhext.c 2004-08-03 15:55:40.000000000 -0500
@@ -82,7 +82,8 @@ make_parent_path(name)
register char *p;
/* make parent directory name into PATH for recursive call */
- strcpy(path, name);
+ memset(path, 0, sizeof(path));
+ strncpy(path, name, sizeof(path)-1);
for (p = path + strlen(path); p > path; p--)
if (p[-1] == '/') {
*--p = '\0';
@@ -212,9 +213,11 @@ extract_one(afp, hdr)
}
if (extract_directory)
- sprintf(name, "%s/%s", extract_directory, q);
- else
- strcpy(name, q);
+ snprintf(name, sizeof(name), "%s/%s", extract_directory, q);
+ else {
+ strncpy(name, q, sizeof(name));
+ name[sizeof(name) - 1] = '\0';
+ }
/* LZHDIRS_METHOD�����ĥإå��������å����� */
@@ -335,7 +338,8 @@ extract_one(afp, hdr)
if ((hdr->unix_mode & UNIX_FILE_TYPEMASK) == UNIX_FILE_SYMLINK) {
char buf[256], *bb1, *bb2;
int l_code;
- strcpy(buf, name);
+ strncpy(buf, name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
bb1 = strtok(buf, "|");
bb2 = strtok(NULL, "|");
@@ -365,9 +369,10 @@ extract_one(afp, hdr)
if (quiet != TRUE) {
printf("Symbolic Link %s -> %s\n", bb1, bb2);
}
- strcpy(name, bb1); /* Symbolic's name set */
+ strncpy(name, bb1, 255); /* Symbolic's name set */
+ name[255] = 0;
#else
- sprintf(buf, "%s -> %s", bb1, bb2);
+ sprintf(buf, sizeof(buf), "%s -> %s", bb1, bb2);
warning("Can't make Symbolic Link", buf);
return;
#endif
diff -urNp lha-114i.orig/src/lhlist.c lha-114i/src/lhlist.c
--- lha-114i.orig/src/lhlist.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhlist.c 2004-08-03 15:54:05.000000000 -0500
@@ -250,7 +250,8 @@ list_one(hdr)
printf(" %s", hdr->name);
else {
char buf[256], *b1, *b2;
- strcpy(buf, hdr->name);
+ strncpy(buf, hdr->name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
b1 = strtok(buf, "|");
b2 = strtok(NULL, "|");
printf(" %s -> %s", b1, b2);
diff -urNp lha-114i.orig/src/util.c lha-114i/src/util.c
--- lha-114i.orig/src/util.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/util.c 2004-08-03 15:54:05.000000000 -0500
@@ -276,21 +276,27 @@ rmdir(path)
char *path;
{
int stat, rtn = 0;
- char *cmdname;
- if ((cmdname = (char *) malloc(strlen(RMDIRPATH) + 1 + strlen(path) + 1))
- == 0)
+ pid_t child;
+
+
+ /* XXX thomas: shell meta chars in path could exec commands */
+ /* therefore we should avoid using system() */
+ if ((child = fork()) < 0)
+ return (-1); /* fork error */
+ else if (child) { /* parent process */
+ while (child != wait(&stat)) /* ignore signals */
+ continue;
+ }
+ else { /* child process */
+ execl(RMDIRPATH, "rmdir", path, (char *) 0);
+ /* never come here except execl is error */
return (-1);
- strcpy(cmdname, RMDIRPATH);
- *(cmdname + strlen(RMDIRPATH)) = ' ';
- strcpy(cmdname + strlen(RMDIRPATH) + 1, path);
- if ((stat = system(cmdname)) < 0)
- rtn = -1; /* fork or exec error */
- else if (stat) { /* RMDIR command error */
- errno = EIO;
- rtn = -1;
}
- free(cmdname);
- return (rtn);
+ if (stat != 0) {
+ errno = EIO; /* cannot get error num. */
+ return (-1);
+ }
+ return (0);
}
/* ------------------------------------------------------------------------ */
lha-1.14i-symlink.patch:
--- NEW FILE lha-1.14i-symlink.patch ---
--- lha-114i/src/lhext.c.symlink 2000-10-04 10:57:38.000000000 -0400
+++ lha-114i/src/lhext.c 2003-05-19 22:55:57.000000000 -0400
@@ -351,6 +351,7 @@ extract_one(afp, hdr)
}
unlink(bb1);
+ make_parent_path(bb1);
l_code = symlink(bb2, bb1);
if (l_code < 0) {
if (quiet != TRUE)
--- NEW FILE lha.spec ---
Name: lha
Version: 1.14i
Release: 21%{?dist}
Summary: Archiving and compression utility for LHarc/lha/lzh archives
Group: Applications/Archiving
License: Distributable
URL: http://www2m.biglobe.ne.jp/~dolphin/lha/prog/
Source0: http://www2m.biglobe.ne.jp/~dolphin/%{name}/prog/%{name}-114i.tar.gz
Patch0: lha-1.14i-symlink.patch
Patch1: lha-1.14i-malloc.patch
Patch2: lha-1.14i-sec.patch
Patch3: lha-1.14i-dir_length_bounds_check.patch
Patch4: lha-1.14i-sec2.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%description
LHA is an archiving and compression utility for LHarc/lha/lzh format archives.
%prep
%setup -qn lha-114i
%patch0 -p1 -b .symlink
%patch1 -p1 -b .malloc
# security fixes
%patch2 -p1 -b .sec
%patch3 -p1 -b .sec
%patch4 -p1 -b .sec
# Rename doc files to better represent encoding which is EUC (jp)
mv change-114e.txt change-114e.euc
mv change-114g.txt change-114g.euc
mv change-114h.txt change-114h.euc
mv change-114i.txt change-114i.euc
%build
make %{?_smp_mflags} OPTIMIZE="%{optflags} -DSUPPORT_LH7 -DMKSTEMP"
%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
install -m0755 src/lha %{buildroot}%{_bindir}
%clean
rm -rf %{buildroot}
%files
%defattr(-,root,root,-)
%doc change-114* CHANGES.euc PROBLEMS.euc README.euc
%{_bindir}/lha
%changelog
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
- Release bump for rpmfusion build
* Sun Jan 14 2007 Ian Chapman <packages(a)amiga-hardware.com> 1.14i-20%{?dist}
- Initial dribble release
- Aesthetic spec clean-ups for publishing in dribble
- Use %%{?_smp_mflags}
- Use %%{optflags}
- Changed the description (it's saner IMHO)
- Include changelogs
- Dropped MACHINES*, useless to end user
- Changed license field from freeware to distributable
* Fri Feb 10 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2.1
- bump again for double-long bug on ppc(64)
* Tue Feb 07 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2
- rebuilt for new gcc4.1 snapshot and glibc changes
* Fri Dec 09 2005 Jesse Keating <jkeating(a)redhat.com>
- rebuilt
* Sat Mar 05 2005 Than Ngo <than(a)redhat.com> 1.14i-19
- rebuilt
* Wed Feb 09 2005 Than Ngo <than(a)redhat.com> 1.14i-18
- rebuilt
* Fri Sep 10 2004 Than Ngo <than(a)redhat.com> 1.14i-17
- security vulnerabilities CAN-2004-0769, CAN-2004-0771, CAN-2004-0694, CAN-2004-0745
* Tue Jun 15 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Fri May 21 2004 Than Ngo <than(a)redhat.com> 1.14i-15
- fix segmentation fault on ia64
* Wed May 05 2004 Than Ngo <than(a)redhat.com> 1.14i-14
- fix security vulnerabilities, CAN-2004-0234, CAN-2004-0235
* Fri Feb 13 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Wed Jun 04 2003 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Tue May 20 2003 Than Ngo <than(a)redhat.com> 1.14i-11
- add patch file from Matt Wilson, bug #91206
* Wed Jan 22 2003 Tim Powers <timp(a)redhat.com>
- rebuilt
* Wed Dec 11 2002 Tim Powers <timp(a)redhat.com> 1.14i-8
- rebuild on all arches
* Fri Jun 21 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Jun 19 2002 Than Ngo <than(a)redhat.com> 1.14i-6
- don't forcibly strip binaries
* Thu May 23 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Feb 27 2002 Than Ngo <than(a)redhat.com> 1.14i-4
- rebuild
* Tue Jan 29 2002 Than Ngo <than(a)redhat.com> 1.14i-3
- rebuild in rawhide
* Tue Sep 25 2001 Than Ngo <than(a)redhat.com> 1.14i-1
- update to 1.14i (bug #52779)
* Mon May 21 2001 Tim Powers <timp(a)redhat.com>
- rebuilt for the distro
* Mon Jul 24 2000 Prospector <prospector(a)redhat.com>
- rebuilt
* Wed Jul 12 2000 Than Ngo <than(a)redhat.de>
- rebuilt
* Mon Jul 03 2000 Prospector <bugzilla(a)redhat.com>
- automatic rebuild
* Fri May 12 2000 Tim Powers <timp(a)redhat.com>
- rebuilt for Powertools-7.0
* Wed Jan 19 2000 Bill Nottingham <notting(a)redhat.com>
- add some more docs
* Sun Mar 21 1999 Cristian Gafton <gafton(a)redhat.com>
- auto rebuild in the new build environment (release 11)
* Tue Jan 24 1999 Michael Maher <mike(a)redhat.com>
- this package will never change.
- changed groups
* Thu Dec 17 1998 Michael Maher <mike(a)redhat.com>
- built package for 6.0
* Wed Sep 23 1998 Jeff Johnson <jbj(a)redhat.com>
- add english doco.
* Sat Aug 15 1998 Jeff Johnson <jbj(a)redhat.com>
- build root
* Mon Apr 27 1998 Prospector System <bugs(a)redhat.com>
- translations modified for de, fr, tr
* Tue Oct 21 1997 Donnie Barnes <djb(a)redhat.com>
- removed man page, wasn't ASCII and caused more harm than good
- spec file cleanups
* Thu Jul 10 1997 Erik Troan <ewt(a)redhat.com>
- built against glibc
16 years, 7 months
rpms/lha/F-9 lha-1.14i-dir_length_bounds_check.patch, NONE, 1.1 lha-1.14i-malloc.patch, NONE, 1.1 lha-1.14i-sec.patch, NONE, 1.1 lha-1.14i-sec2.patch, NONE, 1.1 lha-1.14i-symlink.patch, NONE, 1.1 lha.spec, NONE, 1.1 .cvsignore, 1.1, 1.2 sources, 1.1, 1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/nonfree/rpms/lha/F-9
In directory se02.es.rpmfusion.net:/tmp/cvs-serv5552
Modified Files:
.cvsignore sources
Added Files:
lha-1.14i-dir_length_bounds_check.patch lha-1.14i-malloc.patch
lha-1.14i-sec.patch lha-1.14i-sec2.patch
lha-1.14i-symlink.patch lha.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
- Release bump for rpmfusion build
lha-1.14i-dir_length_bounds_check.patch:
--- NEW FILE lha-1.14i-dir_length_bounds_check.patch ---
--- lha-114i.orig/src/header.c 2002-07-19 17:23:58.000000000 +0900
+++ lha-114i/src/header.c 2004-06-16 09:49:23.000000000 +0900
@@ -648,8 +648,17 @@
}
if (dir_length) {
+ if ((dir_length + name_length) > sizeof(dirname)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
strcat(dirname, hdr->name);
- strcpy(hdr->name, dirname);
+
+ if ((dir_length + name_length) > sizeof(hdr->name)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
+ strncpy(hdr->name, dirname, sizeof(hdr->name));
name_length += dir_length;
}
lha-1.14i-malloc.patch:
--- NEW FILE lha-1.14i-malloc.patch ---
--- lha-114i/src/lha.h.orig 2004-05-19 19:24:19.000000000 -0400
+++ lha-114i/src/lha.h 2004-05-19 19:23:19.000000000 -0400
@@ -16,6 +16,7 @@
#include <sys/types.h>
#include <sys/file.h>
#include <sys/stat.h>
+#include <malloc.h>
#include <signal.h>
lha-1.14i-sec.patch:
--- NEW FILE lha-1.14i-sec.patch ---
--- lha-114i/src/header.c.orig 2000-10-05 19:36:03.000000000 +0200
+++ lha-114i/src/header.c 2004-04-21 14:30:52.000000000 +0200
@@ -538,6 +538,10 @@
/*
* filename
*/
+ if (header_size >= 256) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #1\n");
+ exit(109);
+ }
for (i = 0; i < header_size - 3; i++)
hdr->name[i] = (char) get_byte();
hdr->name[header_size - 3] = '\0';
@@ -547,6 +551,10 @@
/*
* directory
*/
+ if (header_size >= FILENAME_LENGTH) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #2\n");
+ exit(110);
+ }
for (i = 0; i < header_size - 3; i++)
dirname[i] = (char) get_byte();
dirname[header_size - 3] = '\0';
--- lha-114i/src/lhext.c.orig 2000-10-04 16:57:38.000000000 +0200
+++ lha-114i/src/lhext.c 2004-04-21 14:30:52.000000000 +0200
@@ -190,8 +190,13 @@
q = (char *) rindex(hdr->name, '/') + 1;
}
else {
+ if (is_directory_traversal(q)) {
+ fprintf(stderr, "Possible directory traversal hack attempt in %s\n", q);
+ exit(111);
+ }
+
if (*q == '/') {
- q++;
+ while (*q == '/') { q++; }
/*
* if OSK then strip device name
*/
@@ -419,6 +424,33 @@
return;
}
+int
+is_directory_traversal(char *string)
+{
+ unsigned int type = 0; /* 0 = new, 1 = only dots, 2 = other chars than dots */
+ char *temp;
+
+ temp = string;
+
+ while (*temp != 0) {
+ if (temp[0] == '/') {
+ if (type == 1) { return 1; }
+ type = 0;
+ temp++;
+ continue;
+ }
+
+ if ((temp[0] == '.') && (type < 2))
+ type = 1;
+ if (temp[0] != '.')
+ type = 2;
+
+ temp++;
+ } /* while */
+
+ return (type == 1);
+}
+
/* Local Variables: */
/* mode:c */
/* tab-width:4 */
lha-1.14i-sec2.patch:
--- NEW FILE lha-1.14i-sec2.patch ---
diff -urNp lha-114i.orig/src/lha_macro.h lha-114i/src/lha_macro.h
--- lha-114i.orig/src/lha_macro.h 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lha_macro.h 2004-08-03 15:54:05.000000000 -0500
@@ -53,7 +53,7 @@
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
-#endif /* SEEK_SET
+#endif /* SEEK_SET */
/* non-integral functions */
diff -urNp lha-114i.orig/src/lharc.c lha-114i/src/lharc.c
--- lha-114i.orig/src/lharc.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lharc.c 2004-08-03 15:54:05.000000000 -0500
@@ -830,9 +830,10 @@ find_files(name, v_filec, v_filev)
DIRENTRY *dp;
struct stat tmp_stbuf, arc_stbuf, fil_stbuf;
- strcpy(newname, name);
+ strncpy(newname, name, sizeof(newname));
+ newname[sizeof(newname)-1] = 0;
len = strlen(name);
- if (len > 0 && newname[len - 1] != '/')
+ if (len > 0 && newname[len - 1] != '/' && len < (sizeof(newname)-1))
newname[len++] = '/';
dirp = opendir(name);
@@ -846,6 +847,11 @@ find_files(name, v_filec, v_filev)
for (dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
n = NAMLEN(dp);
+ if (len >= (sizeof(newname)-1) ||
+ (len+n) >= (sizeof(newname)-1) ||
+ n <= 0 ||
+ (len+n) <= 0)
+ break;
strncpy(newname + len, dp->d_name, n);
newname[len + n] = '\0';
if (GETSTAT(newname, &fil_stbuf) < 0)
@@ -903,7 +909,8 @@ build_temporary_name()
strcpy(temporary_name, TMP_FILENAME_TEMPLATE);
}
else {
- sprintf(temporary_name, "%s/lhXXXXXX", extract_directory);
+ snprintf(temporary_name, sizeof(temporary_name),
+ "%s/lhXXXXXX", extract_directory);
}
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -913,10 +920,16 @@ build_temporary_name()
#else
char *p, *s;
- strcpy(temporary_name, archive_name);
+ strncpy(temporary_name, archive_name, sizeof(temporary_name));
+ temporary_name[sizeof(temporary_name)-1] = 0;
for (p = temporary_name, s = (char *) 0; *p; p++)
if (*p == '/')
s = p;
+
+ if( sizeof(temporary_name) - ((size_t) (s-temporary_name)) - 1
+ <= strlen("lhXXXXXX"))
+ exit(-1);
+
strcpy((s ? s + 1 : temporary_name), "lhXXXXXX");
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -1052,7 +1065,8 @@ open_old_archive()
if (open_old_archive_1(archive_name, &fp))
return fp;
- sprintf(expanded_archive_name, "%s.lzh", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzh", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
@@ -1061,7 +1075,8 @@ open_old_archive()
* if ( (errno&0xffff)!=E_PNNF ) { archive_name =
* expanded_archive_name; return NULL; }
*/
- sprintf(expanded_archive_name, "%s.lzs", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzs", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
diff -urNp lha-114i.orig/src/lhext.c lha-114i/src/lhext.c
--- lha-114i.orig/src/lhext.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhext.c 2004-08-03 15:55:40.000000000 -0500
@@ -82,7 +82,8 @@ make_parent_path(name)
register char *p;
/* make parent directory name into PATH for recursive call */
- strcpy(path, name);
+ memset(path, 0, sizeof(path));
+ strncpy(path, name, sizeof(path)-1);
for (p = path + strlen(path); p > path; p--)
if (p[-1] == '/') {
*--p = '\0';
@@ -212,9 +213,11 @@ extract_one(afp, hdr)
}
if (extract_directory)
- sprintf(name, "%s/%s", extract_directory, q);
- else
- strcpy(name, q);
+ snprintf(name, sizeof(name), "%s/%s", extract_directory, q);
+ else {
+ strncpy(name, q, sizeof(name));
+ name[sizeof(name) - 1] = '\0';
+ }
/* LZHDIRS_METHOD�����ĥإå��������å����� */
@@ -335,7 +338,8 @@ extract_one(afp, hdr)
if ((hdr->unix_mode & UNIX_FILE_TYPEMASK) == UNIX_FILE_SYMLINK) {
char buf[256], *bb1, *bb2;
int l_code;
- strcpy(buf, name);
+ strncpy(buf, name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
bb1 = strtok(buf, "|");
bb2 = strtok(NULL, "|");
@@ -365,9 +369,10 @@ extract_one(afp, hdr)
if (quiet != TRUE) {
printf("Symbolic Link %s -> %s\n", bb1, bb2);
}
- strcpy(name, bb1); /* Symbolic's name set */
+ strncpy(name, bb1, 255); /* Symbolic's name set */
+ name[255] = 0;
#else
- sprintf(buf, "%s -> %s", bb1, bb2);
+ sprintf(buf, sizeof(buf), "%s -> %s", bb1, bb2);
warning("Can't make Symbolic Link", buf);
return;
#endif
diff -urNp lha-114i.orig/src/lhlist.c lha-114i/src/lhlist.c
--- lha-114i.orig/src/lhlist.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhlist.c 2004-08-03 15:54:05.000000000 -0500
@@ -250,7 +250,8 @@ list_one(hdr)
printf(" %s", hdr->name);
else {
char buf[256], *b1, *b2;
- strcpy(buf, hdr->name);
+ strncpy(buf, hdr->name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
b1 = strtok(buf, "|");
b2 = strtok(NULL, "|");
printf(" %s -> %s", b1, b2);
diff -urNp lha-114i.orig/src/util.c lha-114i/src/util.c
--- lha-114i.orig/src/util.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/util.c 2004-08-03 15:54:05.000000000 -0500
@@ -276,21 +276,27 @@ rmdir(path)
char *path;
{
int stat, rtn = 0;
- char *cmdname;
- if ((cmdname = (char *) malloc(strlen(RMDIRPATH) + 1 + strlen(path) + 1))
- == 0)
+ pid_t child;
+
+
+ /* XXX thomas: shell meta chars in path could exec commands */
+ /* therefore we should avoid using system() */
+ if ((child = fork()) < 0)
+ return (-1); /* fork error */
+ else if (child) { /* parent process */
+ while (child != wait(&stat)) /* ignore signals */
+ continue;
+ }
+ else { /* child process */
+ execl(RMDIRPATH, "rmdir", path, (char *) 0);
+ /* never come here except execl is error */
return (-1);
- strcpy(cmdname, RMDIRPATH);
- *(cmdname + strlen(RMDIRPATH)) = ' ';
- strcpy(cmdname + strlen(RMDIRPATH) + 1, path);
- if ((stat = system(cmdname)) < 0)
- rtn = -1; /* fork or exec error */
- else if (stat) { /* RMDIR command error */
- errno = EIO;
- rtn = -1;
}
- free(cmdname);
- return (rtn);
+ if (stat != 0) {
+ errno = EIO; /* cannot get error num. */
+ return (-1);
+ }
+ return (0);
}
/* ------------------------------------------------------------------------ */
lha-1.14i-symlink.patch:
--- NEW FILE lha-1.14i-symlink.patch ---
--- lha-114i/src/lhext.c.symlink 2000-10-04 10:57:38.000000000 -0400
+++ lha-114i/src/lhext.c 2003-05-19 22:55:57.000000000 -0400
@@ -351,6 +351,7 @@ extract_one(afp, hdr)
}
unlink(bb1);
+ make_parent_path(bb1);
l_code = symlink(bb2, bb1);
if (l_code < 0) {
if (quiet != TRUE)
--- NEW FILE lha.spec ---
Name: lha
Version: 1.14i
Release: 21%{?dist}
Summary: Archiving and compression utility for LHarc/lha/lzh archives
Group: Applications/Archiving
License: Distributable
URL: http://www2m.biglobe.ne.jp/~dolphin/lha/prog/
Source0: http://www2m.biglobe.ne.jp/~dolphin/%{name}/prog/%{name}-114i.tar.gz
Patch0: lha-1.14i-symlink.patch
Patch1: lha-1.14i-malloc.patch
Patch2: lha-1.14i-sec.patch
Patch3: lha-1.14i-dir_length_bounds_check.patch
Patch4: lha-1.14i-sec2.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%description
LHA is an archiving and compression utility for LHarc/lha/lzh format archives.
%prep
%setup -qn lha-114i
%patch0 -p1 -b .symlink
%patch1 -p1 -b .malloc
# security fixes
%patch2 -p1 -b .sec
%patch3 -p1 -b .sec
%patch4 -p1 -b .sec
# Rename doc files to better represent encoding which is EUC (jp)
mv change-114e.txt change-114e.euc
mv change-114g.txt change-114g.euc
mv change-114h.txt change-114h.euc
mv change-114i.txt change-114i.euc
%build
make %{?_smp_mflags} OPTIMIZE="%{optflags} -DSUPPORT_LH7 -DMKSTEMP"
%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
install -m0755 src/lha %{buildroot}%{_bindir}
%clean
rm -rf %{buildroot}
%files
%defattr(-,root,root,-)
%doc change-114* CHANGES.euc PROBLEMS.euc README.euc
%{_bindir}/lha
%changelog
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
- Release bump for rpmfusion build
* Sun Jan 14 2007 Ian Chapman <packages(a)amiga-hardware.com> 1.14i-20%{?dist}
- Initial dribble release
- Aesthetic spec clean-ups for publishing in dribble
- Use %%{?_smp_mflags}
- Use %%{optflags}
- Changed the description (it's saner IMHO)
- Include changelogs
- Dropped MACHINES*, useless to end user
- Changed license field from freeware to distributable
* Fri Feb 10 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2.1
- bump again for double-long bug on ppc(64)
* Tue Feb 07 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2
- rebuilt for new gcc4.1 snapshot and glibc changes
* Fri Dec 09 2005 Jesse Keating <jkeating(a)redhat.com>
- rebuilt
* Sat Mar 05 2005 Than Ngo <than(a)redhat.com> 1.14i-19
- rebuilt
* Wed Feb 09 2005 Than Ngo <than(a)redhat.com> 1.14i-18
- rebuilt
* Fri Sep 10 2004 Than Ngo <than(a)redhat.com> 1.14i-17
- security vulnerabilities CAN-2004-0769, CAN-2004-0771, CAN-2004-0694, CAN-2004-0745
* Tue Jun 15 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Fri May 21 2004 Than Ngo <than(a)redhat.com> 1.14i-15
- fix segmentation fault on ia64
* Wed May 05 2004 Than Ngo <than(a)redhat.com> 1.14i-14
- fix security vulnerabilities, CAN-2004-0234, CAN-2004-0235
* Fri Feb 13 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Wed Jun 04 2003 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Tue May 20 2003 Than Ngo <than(a)redhat.com> 1.14i-11
- add patch file from Matt Wilson, bug #91206
* Wed Jan 22 2003 Tim Powers <timp(a)redhat.com>
- rebuilt
* Wed Dec 11 2002 Tim Powers <timp(a)redhat.com> 1.14i-8
- rebuild on all arches
* Fri Jun 21 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Jun 19 2002 Than Ngo <than(a)redhat.com> 1.14i-6
- don't forcibly strip binaries
* Thu May 23 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Feb 27 2002 Than Ngo <than(a)redhat.com> 1.14i-4
- rebuild
* Tue Jan 29 2002 Than Ngo <than(a)redhat.com> 1.14i-3
- rebuild in rawhide
* Tue Sep 25 2001 Than Ngo <than(a)redhat.com> 1.14i-1
- update to 1.14i (bug #52779)
* Mon May 21 2001 Tim Powers <timp(a)redhat.com>
- rebuilt for the distro
* Mon Jul 24 2000 Prospector <prospector(a)redhat.com>
- rebuilt
* Wed Jul 12 2000 Than Ngo <than(a)redhat.de>
- rebuilt
* Mon Jul 03 2000 Prospector <bugzilla(a)redhat.com>
- automatic rebuild
* Fri May 12 2000 Tim Powers <timp(a)redhat.com>
- rebuilt for Powertools-7.0
* Wed Jan 19 2000 Bill Nottingham <notting(a)redhat.com>
- add some more docs
* Sun Mar 21 1999 Cristian Gafton <gafton(a)redhat.com>
- auto rebuild in the new build environment (release 11)
* Tue Jan 24 1999 Michael Maher <mike(a)redhat.com>
- this package will never change.
- changed groups
* Thu Dec 17 1998 Michael Maher <mike(a)redhat.com>
- built package for 6.0
* Wed Sep 23 1998 Jeff Johnson <jbj(a)redhat.com>
- add english doco.
* Sat Aug 15 1998 Jeff Johnson <jbj(a)redhat.com>
- build root
* Mon Apr 27 1998 Prospector System <bugs(a)redhat.com>
- translations modified for de, fr, tr
* Tue Oct 21 1997 Donnie Barnes <djb(a)redhat.com>
- removed man page, wasn't ASCII and caused more harm than good
- spec file cleanups
* Thu Jul 10 1997 Erik Troan <ewt(a)redhat.com>
- built against glibc
Index: .cvsignore
===================================================================
RCS file: /cvs/nonfree/rpms/lha/F-9/.cvsignore,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- .cvsignore 1 Jun 2008 15:44:11 -0000 1.1
+++ .cvsignore 24 Jul 2008 11:23:48 -0000 1.2
@@ -0,0 +1 @@
+lha-114i.tar.gz
Index: sources
===================================================================
RCS file: /cvs/nonfree/rpms/lha/F-9/sources,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- sources 1 Jun 2008 15:44:11 -0000 1.1
+++ sources 24 Jul 2008 11:23:48 -0000 1.2
@@ -0,0 +1 @@
+5225884d557b91f04124693e2c5c9e94 lha-114i.tar.gz
16 years, 7 months
rpms/lha/devel lha.spec,1.1,1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/nonfree/rpms/lha/devel
In directory se02.es.rpmfusion.net:/tmp/cvs-serv5424
Modified Files:
lha.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
- Release bump for rpmfusion build
Index: lha.spec
===================================================================
RCS file: /cvs/nonfree/rpms/lha/devel/lha.spec,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- lha.spec 24 Jul 2008 09:47:12 -0000 1.1
+++ lha.spec 24 Jul 2008 11:22:52 -0000 1.2
@@ -1,6 +1,6 @@
Name: lha
Version: 1.14i
-Release: 20%{?dist}
+Release: 21%{?dist}
Summary: Archiving and compression utility for LHarc/lha/lzh archives
Group: Applications/Archiving
License: Distributable
@@ -49,12 +49,15 @@
%files
-%defattr(-,root,root)
+%defattr(-,root,root,-)
%doc change-114* CHANGES.euc PROBLEMS.euc README.euc
%{_bindir}/lha
%changelog
+* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 1.14i-21
+- Release bump for rpmfusion build
+
* Sun Jan 14 2007 Ian Chapman <packages(a)amiga-hardware.com> 1.14i-20%{?dist}
- Initial dribble release
- Aesthetic spec clean-ups for publishing in dribble
16 years, 7 months
rpms/gstreamer-plugins-bad/F-8 gstreamer-plugins-bad.spec,1.1,1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/gstreamer-plugins-bad/F-8
In directory se02.es.rpmfusion.net:/tmp/cvs-serv311
Modified Files:
gstreamer-plugins-bad.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.5-15
- Release bump for rpmfusion
Index: gstreamer-plugins-bad.spec
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-bad/F-8/gstreamer-plugins-bad.spec,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- gstreamer-plugins-bad.spec 24 Jul 2008 09:27:42 -0000 1.1
+++ gstreamer-plugins-bad.spec 24 Jul 2008 09:51:10 -0000 1.2
@@ -11,7 +11,7 @@
Summary: GStreamer streaming media framework "bad" plug-ins
Name: gstreamer-plugins-bad
Version: 0.10.5
-Release: 14%{?dist}
+Release: 15%{?dist}
License: LGPLv2+
Group: Applications/Multimedia
URL: http://gstreamer.freedesktop.org/
@@ -240,6 +240,9 @@
%changelog
+* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.5-15
+- Release bump for rpmfusion
+
* Tue Feb 5 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.5-14
- Add flv demuxer from CVS (livna bug 1846)
16 years, 7 months
rpms/gstreamer-plugins-ugly/F-8 gst-plugins-ugly-0.10.6-asf-seek.patch, NONE, 1.1 gst-plugins-ugly-0.10.6-dvdread.patch, NONE, 1.1 gstreamer-plugins-ugly-mpegaudioparse.patch, NONE, 1.1 gstreamer-plugins-ugly.spec, NONE, 1.1 .cvsignore, 1.1, 1.2 sources, 1.1, 1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/gstreamer-plugins-ugly/F-8
In directory se02.es.rpmfusion.net:/tmp/cvs-serv32669
Modified Files:
.cvsignore sources
Added Files:
gst-plugins-ugly-0.10.6-asf-seek.patch
gst-plugins-ugly-0.10.6-dvdread.patch
gstreamer-plugins-ugly-mpegaudioparse.patch
gstreamer-plugins-ugly.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.6-6
- Release bump for rpmfusion
gst-plugins-ugly-0.10.6-asf-seek.patch:
--- NEW FILE gst-plugins-ugly-0.10.6-asf-seek.patch ---
diff -up gst-plugins-ugly-0.10.6/ext/dvdread/dvdreadsrc.c.dvdread gst-plugins-ugly-0.10.6/ext/dvdread/dvdreadsrc.c
--- gst-plugins-ugly-0.10.6/ext/dvdread/dvdreadsrc.c.dvdread 2007-12-18 14:48:23.000000000 +0100
+++ gst-plugins-ugly-0.10.6/ext/dvdread/dvdreadsrc.c 2007-12-18 14:48:58.000000000 +0100
@@ -777,21 +777,21 @@ again:
}
/* read NAV packet */
-nav_retry:
-
len = DVDReadBlocks (src->dvd_title, src->cur_pack, 1, oneblock);
- if (len == 0)
+ if (len != 1)
goto read_error;
if (!gst_dvd_read_src_is_nav_pack (oneblock)) {
- GST_LOG_OBJECT (src, "Skipping nav packet @ pack %d", src->cur_pack);
- src->cur_pack++;
- goto nav_retry;
+ GST_LOG_OBJECT (src, "Expected nav packet @ pack %d", src->cur_pack);
+ goto read_error;
}
/* parse the contained dsi packet */
navRead_DSI (&dsi_pack, &oneblock[DSI_START_BYTE]);
- g_assert (src->cur_pack == dsi_pack.dsi_gi.nv_pck_lbn);
+ if (src->cur_pack != dsi_pack.dsi_gi.nv_pck_lbn) {
+ GST_ERROR ("src->cur_pack = %d, dsi_pack.dsi_gi.nv_pck_lbn = %d",
+ src->cur_pack, dsi_pack.dsi_gi.nv_pck_lbn);
+ }
/* determine where we go next. These values are the ones we
* mostly care about */
gstreamer-plugins-ugly-mpegaudioparse.patch:
--- NEW FILE gstreamer-plugins-ugly-mpegaudioparse.patch ---
diff -up gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.h.orig gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.h
--- gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.h.orig 2007-06-13 11:21:26.000000000 +0200
+++ gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.h 2007-09-02 15:05:01.000000000 +0200
@@ -82,6 +82,9 @@ struct _GstMPEGAudioParse {
guchar xing_seek_table[100];
guint32 xing_vbr_scale;
guint xing_bitrate;
+
+ /* pending segment */
+ GstEvent *pending_segment;
};
struct _GstMPEGAudioParseClass {
diff -up gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.c.orig gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.c
--- gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.c.orig 2007-06-13 11:21:26.000000000 +0200
+++ gst-plugins-ugly-0.10.6/gst/mpegaudioparse/gstmpegaudioparse.c 2007-09-02 15:04:25.000000000 +0200
@@ -329,6 +329,7 @@ gst_mp3parse_sink_event (GstPad * pad, G
{
gboolean res;
GstMPEGAudioParse *mp3parse;
+ GstEvent **eventp;
mp3parse = GST_MP3PARSE (gst_pad_get_parent (pad));
@@ -379,12 +380,18 @@ gst_mp3parse_sink_event (GstPad * pad, G
GST_DEBUG_OBJECT (mp3parse, "Pushing newseg rate %g, applied rate %g, "
"format %d, start %lld, stop %lld, pos %lld\n",
rate, applied_rate, format, start, stop, pos);
- res = gst_pad_push_event (mp3parse->srcpad, event);
+ /* save the segment for later, right before we push a new buffer so that
+ * the caps are fixed and the next linked element can receive the segment. */
+ eventp = &mp3parse->pending_segment;
+ gst_event_replace (eventp, event);
+ res = TRUE;
break;
}
case GST_EVENT_FLUSH_STOP:
/* Clear our adapter and set up for a new position */
gst_adapter_clear (mp3parse->adapter);
+ eventp = &mp3parse->pending_segment;
+ gst_event_replace (eventp, NULL);
res = gst_pad_push_event (mp3parse->srcpad, event);
break;
default:
@@ -483,6 +490,12 @@ gst_mp3parse_emit_frame (GstMPEGAudioPar
mp3parse->srcpad, taglist);
}
+ /* push any pending segment now */
+ if (mp3parse->pending_segment) {
+ gst_pad_push_event (mp3parse->srcpad, mp3parse->pending_segment);
+ mp3parse->pending_segment = NULL;
+ }
+
return gst_pad_push (mp3parse->srcpad, outbuf);
}
***** Error reading new file: [Errno 2] No such file or directory: 'gstreamer-plugins-ugly.spec'
Index: .cvsignore
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/F-8/.cvsignore,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- .cvsignore 4 May 2008 13:32:16 -0000 1.1
+++ .cvsignore 24 Jul 2008 09:49:57 -0000 1.2
@@ -0,0 +1 @@
+gst-plugins-ugly-0.10.6.tar.bz2
Index: sources
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/F-8/sources,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- sources 4 May 2008 13:32:16 -0000 1.1
+++ sources 24 Jul 2008 09:49:57 -0000 1.2
@@ -0,0 +1 @@
+f1016148ecbfba968c0ef1773066988b gst-plugins-ugly-0.10.6.tar.bz2
16 years, 7 months
rpms/lha/devel lha-1.14i-dir_length_bounds_check.patch, NONE, 1.1 lha-1.14i-malloc.patch, NONE, 1.1 lha-1.14i-sec.patch, NONE, 1.1 lha-1.14i-sec2.patch, NONE, 1.1 lha-1.14i-symlink.patch, NONE, 1.1 lha.spec, NONE, 1.1 .cvsignore, 1.1, 1.2 sources, 1.1, 1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/nonfree/rpms/lha/devel
In directory se02.es.rpmfusion.net:/tmp/cvs-serv32311/devel
Modified Files:
.cvsignore sources
Added Files:
lha-1.14i-dir_length_bounds_check.patch lha-1.14i-malloc.patch
lha-1.14i-sec.patch lha-1.14i-sec2.patch
lha-1.14i-symlink.patch lha.spec
Log Message:
initial lha import
lha-1.14i-dir_length_bounds_check.patch:
--- NEW FILE lha-1.14i-dir_length_bounds_check.patch ---
--- lha-114i.orig/src/header.c 2002-07-19 17:23:58.000000000 +0900
+++ lha-114i/src/header.c 2004-06-16 09:49:23.000000000 +0900
@@ -648,8 +648,17 @@
}
if (dir_length) {
+ if ((dir_length + name_length) > sizeof(dirname)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
strcat(dirname, hdr->name);
- strcpy(hdr->name, dirname);
+
+ if ((dir_length + name_length) > sizeof(hdr->name)) {
+ fprintf(stderr, "Insufficient buffer size\n");
+ exit(112);
+ }
+ strncpy(hdr->name, dirname, sizeof(hdr->name));
name_length += dir_length;
}
lha-1.14i-malloc.patch:
--- NEW FILE lha-1.14i-malloc.patch ---
--- lha-114i/src/lha.h.orig 2004-05-19 19:24:19.000000000 -0400
+++ lha-114i/src/lha.h 2004-05-19 19:23:19.000000000 -0400
@@ -16,6 +16,7 @@
#include <sys/types.h>
#include <sys/file.h>
#include <sys/stat.h>
+#include <malloc.h>
#include <signal.h>
lha-1.14i-sec.patch:
--- NEW FILE lha-1.14i-sec.patch ---
--- lha-114i/src/header.c.orig 2000-10-05 19:36:03.000000000 +0200
+++ lha-114i/src/header.c 2004-04-21 14:30:52.000000000 +0200
@@ -538,6 +538,10 @@
/*
* filename
*/
+ if (header_size >= 256) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #1\n");
+ exit(109);
+ }
for (i = 0; i < header_size - 3; i++)
hdr->name[i] = (char) get_byte();
hdr->name[header_size - 3] = '\0';
@@ -547,6 +551,10 @@
/*
* directory
*/
+ if (header_size >= FILENAME_LENGTH) {
+ fprintf(stderr, "Possible buffer overflow hack attack, type #2\n");
+ exit(110);
+ }
for (i = 0; i < header_size - 3; i++)
dirname[i] = (char) get_byte();
dirname[header_size - 3] = '\0';
--- lha-114i/src/lhext.c.orig 2000-10-04 16:57:38.000000000 +0200
+++ lha-114i/src/lhext.c 2004-04-21 14:30:52.000000000 +0200
@@ -190,8 +190,13 @@
q = (char *) rindex(hdr->name, '/') + 1;
}
else {
+ if (is_directory_traversal(q)) {
+ fprintf(stderr, "Possible directory traversal hack attempt in %s\n", q);
+ exit(111);
+ }
+
if (*q == '/') {
- q++;
+ while (*q == '/') { q++; }
/*
* if OSK then strip device name
*/
@@ -419,6 +424,33 @@
return;
}
+int
+is_directory_traversal(char *string)
+{
+ unsigned int type = 0; /* 0 = new, 1 = only dots, 2 = other chars than dots */
+ char *temp;
+
+ temp = string;
+
+ while (*temp != 0) {
+ if (temp[0] == '/') {
+ if (type == 1) { return 1; }
+ type = 0;
+ temp++;
+ continue;
+ }
+
+ if ((temp[0] == '.') && (type < 2))
+ type = 1;
+ if (temp[0] != '.')
+ type = 2;
+
+ temp++;
+ } /* while */
+
+ return (type == 1);
+}
+
/* Local Variables: */
/* mode:c */
/* tab-width:4 */
lha-1.14i-sec2.patch:
--- NEW FILE lha-1.14i-sec2.patch ---
diff -urNp lha-114i.orig/src/lha_macro.h lha-114i/src/lha_macro.h
--- lha-114i.orig/src/lha_macro.h 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lha_macro.h 2004-08-03 15:54:05.000000000 -0500
@@ -53,7 +53,7 @@
#define SEEK_SET 0
#define SEEK_CUR 1
#define SEEK_END 2
-#endif /* SEEK_SET
+#endif /* SEEK_SET */
/* non-integral functions */
diff -urNp lha-114i.orig/src/lharc.c lha-114i/src/lharc.c
--- lha-114i.orig/src/lharc.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lharc.c 2004-08-03 15:54:05.000000000 -0500
@@ -830,9 +830,10 @@ find_files(name, v_filec, v_filev)
DIRENTRY *dp;
struct stat tmp_stbuf, arc_stbuf, fil_stbuf;
- strcpy(newname, name);
+ strncpy(newname, name, sizeof(newname));
+ newname[sizeof(newname)-1] = 0;
len = strlen(name);
- if (len > 0 && newname[len - 1] != '/')
+ if (len > 0 && newname[len - 1] != '/' && len < (sizeof(newname)-1))
newname[len++] = '/';
dirp = opendir(name);
@@ -846,6 +847,11 @@ find_files(name, v_filec, v_filev)
for (dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
n = NAMLEN(dp);
+ if (len >= (sizeof(newname)-1) ||
+ (len+n) >= (sizeof(newname)-1) ||
+ n <= 0 ||
+ (len+n) <= 0)
+ break;
strncpy(newname + len, dp->d_name, n);
newname[len + n] = '\0';
if (GETSTAT(newname, &fil_stbuf) < 0)
@@ -903,7 +909,8 @@ build_temporary_name()
strcpy(temporary_name, TMP_FILENAME_TEMPLATE);
}
else {
- sprintf(temporary_name, "%s/lhXXXXXX", extract_directory);
+ snprintf(temporary_name, sizeof(temporary_name),
+ "%s/lhXXXXXX", extract_directory);
}
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -913,10 +920,16 @@ build_temporary_name()
#else
char *p, *s;
- strcpy(temporary_name, archive_name);
+ strncpy(temporary_name, archive_name, sizeof(temporary_name));
+ temporary_name[sizeof(temporary_name)-1] = 0;
for (p = temporary_name, s = (char *) 0; *p; p++)
if (*p == '/')
s = p;
+
+ if( sizeof(temporary_name) - ((size_t) (s-temporary_name)) - 1
+ <= strlen("lhXXXXXX"))
+ exit(-1);
+
strcpy((s ? s + 1 : temporary_name), "lhXXXXXX");
#ifdef MKSTEMP
mkstemp(temporary_name);
@@ -1052,7 +1065,8 @@ open_old_archive()
if (open_old_archive_1(archive_name, &fp))
return fp;
- sprintf(expanded_archive_name, "%s.lzh", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzh", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
@@ -1061,7 +1075,8 @@ open_old_archive()
* if ( (errno&0xffff)!=E_PNNF ) { archive_name =
* expanded_archive_name; return NULL; }
*/
- sprintf(expanded_archive_name, "%s.lzs", archive_name);
+ snprintf(expanded_archive_name, sizeof(expanded_archive_name),
+ "%s.lzs", archive_name);
if (open_old_archive_1(expanded_archive_name, &fp)) {
archive_name = expanded_archive_name;
return fp;
diff -urNp lha-114i.orig/src/lhext.c lha-114i/src/lhext.c
--- lha-114i.orig/src/lhext.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhext.c 2004-08-03 15:55:40.000000000 -0500
@@ -82,7 +82,8 @@ make_parent_path(name)
register char *p;
/* make parent directory name into PATH for recursive call */
- strcpy(path, name);
+ memset(path, 0, sizeof(path));
+ strncpy(path, name, sizeof(path)-1);
for (p = path + strlen(path); p > path; p--)
if (p[-1] == '/') {
*--p = '\0';
@@ -212,9 +213,11 @@ extract_one(afp, hdr)
}
if (extract_directory)
- sprintf(name, "%s/%s", extract_directory, q);
- else
- strcpy(name, q);
+ snprintf(name, sizeof(name), "%s/%s", extract_directory, q);
+ else {
+ strncpy(name, q, sizeof(name));
+ name[sizeof(name) - 1] = '\0';
+ }
/* LZHDIRS_METHOD�����ĥإå��������å����� */
@@ -335,7 +338,8 @@ extract_one(afp, hdr)
if ((hdr->unix_mode & UNIX_FILE_TYPEMASK) == UNIX_FILE_SYMLINK) {
char buf[256], *bb1, *bb2;
int l_code;
- strcpy(buf, name);
+ strncpy(buf, name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
bb1 = strtok(buf, "|");
bb2 = strtok(NULL, "|");
@@ -365,9 +369,10 @@ extract_one(afp, hdr)
if (quiet != TRUE) {
printf("Symbolic Link %s -> %s\n", bb1, bb2);
}
- strcpy(name, bb1); /* Symbolic's name set */
+ strncpy(name, bb1, 255); /* Symbolic's name set */
+ name[255] = 0;
#else
- sprintf(buf, "%s -> %s", bb1, bb2);
+ sprintf(buf, sizeof(buf), "%s -> %s", bb1, bb2);
warning("Can't make Symbolic Link", buf);
return;
#endif
diff -urNp lha-114i.orig/src/lhlist.c lha-114i/src/lhlist.c
--- lha-114i.orig/src/lhlist.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/lhlist.c 2004-08-03 15:54:05.000000000 -0500
@@ -250,7 +250,8 @@ list_one(hdr)
printf(" %s", hdr->name);
else {
char buf[256], *b1, *b2;
- strcpy(buf, hdr->name);
+ strncpy(buf, hdr->name, sizeof(buf));
+ buf[sizeof(buf)-1] = 0;
b1 = strtok(buf, "|");
b2 = strtok(NULL, "|");
printf(" %s -> %s", b1, b2);
diff -urNp lha-114i.orig/src/util.c lha-114i/src/util.c
--- lha-114i.orig/src/util.c 2004-08-03 15:53:56.000000000 -0500
+++ lha-114i/src/util.c 2004-08-03 15:54:05.000000000 -0500
@@ -276,21 +276,27 @@ rmdir(path)
char *path;
{
int stat, rtn = 0;
- char *cmdname;
- if ((cmdname = (char *) malloc(strlen(RMDIRPATH) + 1 + strlen(path) + 1))
- == 0)
+ pid_t child;
+
+
+ /* XXX thomas: shell meta chars in path could exec commands */
+ /* therefore we should avoid using system() */
+ if ((child = fork()) < 0)
+ return (-1); /* fork error */
+ else if (child) { /* parent process */
+ while (child != wait(&stat)) /* ignore signals */
+ continue;
+ }
+ else { /* child process */
+ execl(RMDIRPATH, "rmdir", path, (char *) 0);
+ /* never come here except execl is error */
return (-1);
- strcpy(cmdname, RMDIRPATH);
- *(cmdname + strlen(RMDIRPATH)) = ' ';
- strcpy(cmdname + strlen(RMDIRPATH) + 1, path);
- if ((stat = system(cmdname)) < 0)
- rtn = -1; /* fork or exec error */
- else if (stat) { /* RMDIR command error */
- errno = EIO;
- rtn = -1;
}
- free(cmdname);
- return (rtn);
+ if (stat != 0) {
+ errno = EIO; /* cannot get error num. */
+ return (-1);
+ }
+ return (0);
}
/* ------------------------------------------------------------------------ */
lha-1.14i-symlink.patch:
--- NEW FILE lha-1.14i-symlink.patch ---
--- lha-114i/src/lhext.c.symlink 2000-10-04 10:57:38.000000000 -0400
+++ lha-114i/src/lhext.c 2003-05-19 22:55:57.000000000 -0400
@@ -351,6 +351,7 @@ extract_one(afp, hdr)
}
unlink(bb1);
+ make_parent_path(bb1);
l_code = symlink(bb2, bb1);
if (l_code < 0) {
if (quiet != TRUE)
--- NEW FILE lha.spec ---
Name: lha
Version: 1.14i
Release: 20%{?dist}
Summary: Archiving and compression utility for LHarc/lha/lzh archives
Group: Applications/Archiving
License: Distributable
URL: http://www2m.biglobe.ne.jp/~dolphin/lha/prog/
Source0: http://www2m.biglobe.ne.jp/~dolphin/%{name}/prog/%{name}-114i.tar.gz
Patch0: lha-1.14i-symlink.patch
Patch1: lha-1.14i-malloc.patch
Patch2: lha-1.14i-sec.patch
Patch3: lha-1.14i-dir_length_bounds_check.patch
Patch4: lha-1.14i-sec2.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
%description
LHA is an archiving and compression utility for LHarc/lha/lzh format archives.
%prep
%setup -qn lha-114i
%patch0 -p1 -b .symlink
%patch1 -p1 -b .malloc
# security fixes
%patch2 -p1 -b .sec
%patch3 -p1 -b .sec
%patch4 -p1 -b .sec
# Rename doc files to better represent encoding which is EUC (jp)
mv change-114e.txt change-114e.euc
mv change-114g.txt change-114g.euc
mv change-114h.txt change-114h.euc
mv change-114i.txt change-114i.euc
%build
make %{?_smp_mflags} OPTIMIZE="%{optflags} -DSUPPORT_LH7 -DMKSTEMP"
%install
rm -rf %{buildroot}
mkdir -p %{buildroot}%{_bindir}
install -m0755 src/lha %{buildroot}%{_bindir}
%clean
rm -rf %{buildroot}
%files
%defattr(-,root,root)
%doc change-114* CHANGES.euc PROBLEMS.euc README.euc
%{_bindir}/lha
%changelog
* Sun Jan 14 2007 Ian Chapman <packages(a)amiga-hardware.com> 1.14i-20%{?dist}
- Initial dribble release
- Aesthetic spec clean-ups for publishing in dribble
- Use %%{?_smp_mflags}
- Use %%{optflags}
- Changed the description (it's saner IMHO)
- Include changelogs
- Dropped MACHINES*, useless to end user
- Changed license field from freeware to distributable
* Fri Feb 10 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2.1
- bump again for double-long bug on ppc(64)
* Tue Feb 07 2006 Jesse Keating <jkeating(a)redhat.com> - 1.14i-19.2
- rebuilt for new gcc4.1 snapshot and glibc changes
* Fri Dec 09 2005 Jesse Keating <jkeating(a)redhat.com>
- rebuilt
* Sat Mar 05 2005 Than Ngo <than(a)redhat.com> 1.14i-19
- rebuilt
* Wed Feb 09 2005 Than Ngo <than(a)redhat.com> 1.14i-18
- rebuilt
* Fri Sep 10 2004 Than Ngo <than(a)redhat.com> 1.14i-17
- security vulnerabilities CAN-2004-0769, CAN-2004-0771, CAN-2004-0694, CAN-2004-0745
* Tue Jun 15 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Fri May 21 2004 Than Ngo <than(a)redhat.com> 1.14i-15
- fix segmentation fault on ia64
* Wed May 05 2004 Than Ngo <than(a)redhat.com> 1.14i-14
- fix security vulnerabilities, CAN-2004-0234, CAN-2004-0235
* Fri Feb 13 2004 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Wed Jun 04 2003 Elliot Lee <sopwith(a)redhat.com>
- rebuilt
* Tue May 20 2003 Than Ngo <than(a)redhat.com> 1.14i-11
- add patch file from Matt Wilson, bug #91206
* Wed Jan 22 2003 Tim Powers <timp(a)redhat.com>
- rebuilt
* Wed Dec 11 2002 Tim Powers <timp(a)redhat.com> 1.14i-8
- rebuild on all arches
* Fri Jun 21 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Jun 19 2002 Than Ngo <than(a)redhat.com> 1.14i-6
- don't forcibly strip binaries
* Thu May 23 2002 Tim Powers <timp(a)redhat.com>
- automated rebuild
* Wed Feb 27 2002 Than Ngo <than(a)redhat.com> 1.14i-4
- rebuild
* Tue Jan 29 2002 Than Ngo <than(a)redhat.com> 1.14i-3
- rebuild in rawhide
* Tue Sep 25 2001 Than Ngo <than(a)redhat.com> 1.14i-1
- update to 1.14i (bug #52779)
* Mon May 21 2001 Tim Powers <timp(a)redhat.com>
- rebuilt for the distro
* Mon Jul 24 2000 Prospector <prospector(a)redhat.com>
- rebuilt
* Wed Jul 12 2000 Than Ngo <than(a)redhat.de>
- rebuilt
* Mon Jul 03 2000 Prospector <bugzilla(a)redhat.com>
- automatic rebuild
* Fri May 12 2000 Tim Powers <timp(a)redhat.com>
- rebuilt for Powertools-7.0
* Wed Jan 19 2000 Bill Nottingham <notting(a)redhat.com>
- add some more docs
* Sun Mar 21 1999 Cristian Gafton <gafton(a)redhat.com>
- auto rebuild in the new build environment (release 11)
* Tue Jan 24 1999 Michael Maher <mike(a)redhat.com>
- this package will never change.
- changed groups
* Thu Dec 17 1998 Michael Maher <mike(a)redhat.com>
- built package for 6.0
* Wed Sep 23 1998 Jeff Johnson <jbj(a)redhat.com>
- add english doco.
* Sat Aug 15 1998 Jeff Johnson <jbj(a)redhat.com>
- build root
* Mon Apr 27 1998 Prospector System <bugs(a)redhat.com>
- translations modified for de, fr, tr
* Tue Oct 21 1997 Donnie Barnes <djb(a)redhat.com>
- removed man page, wasn't ASCII and caused more harm than good
- spec file cleanups
* Thu Jul 10 1997 Erik Troan <ewt(a)redhat.com>
- built against glibc
Index: .cvsignore
===================================================================
RCS file: /cvs/nonfree/rpms/lha/devel/.cvsignore,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- .cvsignore 1 Jun 2008 15:44:11 -0000 1.1
+++ .cvsignore 24 Jul 2008 09:47:12 -0000 1.2
@@ -0,0 +1 @@
+lha-114i.tar.gz
Index: sources
===================================================================
RCS file: /cvs/nonfree/rpms/lha/devel/sources,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- sources 1 Jun 2008 15:44:11 -0000 1.1
+++ sources 24 Jul 2008 09:47:12 -0000 1.2
@@ -0,0 +1 @@
+5225884d557b91f04124693e2c5c9e94 lha-114i.tar.gz
16 years, 7 months
rpms/gstreamer-plugins-ugly/F-9 .cvsignore, 1.2, 1.3 gstreamer-plugins-ugly.spec, 1.1, 1.2 sources, 1.2, 1.3 gst-plugins-ugly-0.10.6-asf-seek.patch, 1.1, NONE
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/gstreamer-plugins-ugly/F-9
In directory se02.es.rpmfusion.net:/tmp/cvs-serv32181
Modified Files:
.cvsignore gstreamer-plugins-ugly.spec sources
Removed Files:
gst-plugins-ugly-0.10.6-asf-seek.patch
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-2
- Release bump for rpmfusion
Index: .cvsignore
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/F-9/.cvsignore,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- .cvsignore 4 May 2008 13:35:59 -0000 1.2
+++ .cvsignore 24 Jul 2008 09:45:39 -0000 1.3
@@ -1 +1 @@
-gst-plugins-ugly-0.10.7.tar.bz2
+gst-plugins-ugly-0.10.8.tar.bz2
Index: gstreamer-plugins-ugly.spec
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/F-9/gstreamer-plugins-ugly.spec,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- gstreamer-plugins-ugly.spec 4 May 2008 13:35:59 -0000 1.1
+++ gstreamer-plugins-ugly.spec 24 Jul 2008 09:45:39 -0000 1.2
@@ -10,13 +10,12 @@
Summary: GStreamer streaming media framework "ugly" plug-ins
Name: gstreamer-plugins-ugly
-Version: 0.10.7
-Release: 1%{?dist}
+Version: 0.10.8
+Release: 2%{?dist}
License: LGPLv2+
Group: Applications/Multimedia
URL: http://gstreamer.freedesktop.org/
Source: http://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-%{...
-Patch1: gst-plugins-ugly-0.10.6-asf-seek.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: %{gstreamer} >= %{gst_minver}
BuildRequires: %{gstreamer}-devel >= %{gst_minver}
@@ -56,7 +55,6 @@
%prep
%setup -q -n gst-plugins-ugly-%{version}
-%patch1 -p1
%build
@@ -64,7 +62,8 @@
--with-package-name="gst-plugins-bad rpmfusion rpm" \
--with-package-origin="http://rpmfusion.org/" \
--enable-debug \
- --disable-static
+ --disable-static \
+ --disable-amrnb
%{__make} %{?_smp_mflags}
@@ -104,6 +103,13 @@
%changelog
+* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-2
+- Release bump for rpmfusion
+
+* Thu May 22 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-1
+- New upstream release 0.10.8
+- Drop upstreamed patches
+
* Sun Feb 24 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-1
- New upstream release 0.10.7
- Drop upstreamed patches
Index: sources
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/F-9/sources,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- sources 4 May 2008 13:35:59 -0000 1.2
+++ sources 24 Jul 2008 09:45:39 -0000 1.3
@@ -1 +1 @@
-cff4f55138d12152cf580a3ee71c2519 gst-plugins-ugly-0.10.7.tar.bz2
+090d87a1716eee45a9804ca8558668da gst-plugins-ugly-0.10.8.tar.bz2
--- gst-plugins-ugly-0.10.6-asf-seek.patch DELETED ---
16 years, 7 months
rpms/gstreamer-plugins-ugly/devel .cvsignore, 1.2, 1.3 gstreamer-plugins-ugly.spec, 1.2, 1.3 sources, 1.2, 1.3 gst-plugins-ugly-0.10.6-asf-seek.patch, 1.1, NONE
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/gstreamer-plugins-ugly/devel
In directory se02.es.rpmfusion.net:/tmp/cvs-serv32061
Modified Files:
.cvsignore gstreamer-plugins-ugly.spec sources
Removed Files:
gst-plugins-ugly-0.10.6-asf-seek.patch
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-2
- Release bump for rpmfusion
Index: .cvsignore
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/devel/.cvsignore,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- .cvsignore 4 May 2008 13:35:59 -0000 1.2
+++ .cvsignore 24 Jul 2008 09:43:02 -0000 1.3
@@ -1 +1 @@
-gst-plugins-ugly-0.10.7.tar.bz2
+gst-plugins-ugly-0.10.8.tar.bz2
Index: gstreamer-plugins-ugly.spec
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/devel/gstreamer-plugins-ugly.spec,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- gstreamer-plugins-ugly.spec 24 Jul 2008 09:37:19 -0000 1.2
+++ gstreamer-plugins-ugly.spec 24 Jul 2008 09:43:02 -0000 1.3
@@ -10,13 +10,12 @@
Summary: GStreamer streaming media framework "ugly" plug-ins
Name: gstreamer-plugins-ugly
-Version: 0.10.7
+Version: 0.10.8
Release: 2%{?dist}
License: LGPLv2+
Group: Applications/Multimedia
URL: http://gstreamer.freedesktop.org/
Source: http://gstreamer.freedesktop.org/src/gst-plugins-ugly/gst-plugins-ugly-%{...
-Patch1: gst-plugins-ugly-0.10.6-asf-seek.patch
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: %{gstreamer} >= %{gst_minver}
BuildRequires: %{gstreamer}-devel >= %{gst_minver}
@@ -56,7 +55,6 @@
%prep
%setup -q -n gst-plugins-ugly-%{version}
-%patch1 -p1
%build
@@ -105,9 +103,13 @@
%changelog
-* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-2
+* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-2
- Release bump for rpmfusion
+* Thu May 22 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.8-1
+- New upstream release 0.10.8
+- Drop upstreamed patches
+
* Sun Feb 24 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-1
- New upstream release 0.10.7
- Drop upstreamed patches
Index: sources
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/devel/sources,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -r1.2 -r1.3
--- sources 4 May 2008 13:35:59 -0000 1.2
+++ sources 24 Jul 2008 09:43:02 -0000 1.3
@@ -1 +1 @@
-cff4f55138d12152cf580a3ee71c2519 gst-plugins-ugly-0.10.7.tar.bz2
+090d87a1716eee45a9804ca8558668da gst-plugins-ugly-0.10.8.tar.bz2
--- gst-plugins-ugly-0.10.6-asf-seek.patch DELETED ---
16 years, 7 months
rpms/gstreamer-plugins-ugly/devel gstreamer-plugins-ugly.spec, 1.1, 1.2
by jwrdegoede
Author: jwrdegoede
Update of /cvs/free/rpms/gstreamer-plugins-ugly/devel
In directory se02.es.rpmfusion.net:/tmp/cvs-serv31256
Modified Files:
gstreamer-plugins-ugly.spec
Log Message:
* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-2
- Release bump for rpmfusion
Index: gstreamer-plugins-ugly.spec
===================================================================
RCS file: /cvs/free/rpms/gstreamer-plugins-ugly/devel/gstreamer-plugins-ugly.spec,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -r1.1 -r1.2
--- gstreamer-plugins-ugly.spec 4 May 2008 13:35:59 -0000 1.1
+++ gstreamer-plugins-ugly.spec 24 Jul 2008 09:37:19 -0000 1.2
@@ -11,7 +11,7 @@
Summary: GStreamer streaming media framework "ugly" plug-ins
Name: gstreamer-plugins-ugly
Version: 0.10.7
-Release: 1%{?dist}
+Release: 2%{?dist}
License: LGPLv2+
Group: Applications/Multimedia
URL: http://gstreamer.freedesktop.org/
@@ -64,7 +64,8 @@
--with-package-name="gst-plugins-bad rpmfusion rpm" \
--with-package-origin="http://rpmfusion.org/" \
--enable-debug \
- --disable-static
+ --disable-static \
+ --disable-amrnb
%{__make} %{?_smp_mflags}
@@ -104,6 +105,9 @@
%changelog
+* Wed Jul 23 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-2
+- Release bump for rpmfusion
+
* Sun Feb 24 2008 Hans de Goede <j.w.r.degoede(a)hhs.nl> 0.10.7-1
- New upstream release 0.10.7
- Drop upstreamed patches
16 years, 7 months
diff -up gst-plugins-ugly-0.10.6/gst/asfdemux/gstasfdemux.c.seek gst-plugins-ugly-0.10.6/gst/asfdemux/gstasfdemux.c
--- gst-plugins-ugly-0.10.6/gst/asfdemux/gstasfdemux.c.seek 2007-08-24 14:13:36.000000000 +0200
+++ gst-plugins-ugly-0.10.6/gst/asfdemux/gstasfdemux.c 2007-08-24 14:12:33.000000000 +0200
@@ -492,19 +492,35 @@ gst_asf_demux_handle_seek_event (GstASFD
/* FIXME: should check the KEY_UNIT flag; need to adjust last_stop to
* real start of data and segment_start to indexed time for key unit seek*/
if (!gst_asf_demux_seek_index_lookup (demux, &packet, seek_time, &idx_time)) {
- /* Hackety hack, this sucks. We just seek to an earlier position
- * and let the sinks throw away the stuff before the segment start */
- if (flush && (accurate || keyunit_sync)) {
- seek_time -= 5 * GST_SECOND;
- if (seek_time < 0)
- seek_time = 0;
- }
+ /* First try to query our source to see if it can convert for us. This is
+ the case when our source is an mms stream, notice that in this case
+ gstmms will do a time based seek to get the byte offset, this is not a
+ problem as the seek to this offset needs to happen anway. */
+ gint64 offset;
+ GstFormat dest_format = GST_FORMAT_BYTES;
+
+ if (gst_pad_query_peer_convert (demux->sinkpad, GST_FORMAT_TIME, seek_time,
+ &dest_format, &offset) && dest_format == GST_FORMAT_BYTES) {
+ packet = (offset - demux->data_offset) / demux->packet_size;
+ GST_LOG_OBJECT (demux, "convert %" GST_TIME_FORMAT
+ " to bytes query result: %lld, data_ofset: %llu, packet_size: %u,"
+ " resulting packet: %u\n", GST_TIME_ARGS (seek_time), offset,
+ demux->data_offset, demux->packet_size, packet);
+ } else {
+ /* Hackety hack, this sucks. We just seek to an earlier position
+ * and let the sinks throw away the stuff before the segment start */
+ if (flush && (accurate || keyunit_sync)) {
+ seek_time -= 5 * GST_SECOND;
+ if (seek_time < 0)
+ seek_time = 0;
+ }
- packet = (guint) gst_util_uint64_scale (demux->num_packets,
- seek_time, demux->play_time);
+ packet = (guint) gst_util_uint64_scale (demux->num_packets,
+ seek_time, demux->play_time);
- if (packet > demux->num_packets)
- packet = demux->num_packets;
+ if (packet > demux->num_packets)
+ packet = demux->num_packets;
+ }
} else {
if (keyunit_sync) {
GST_DEBUG_OBJECT (demux, "key unit seek, adjust seek_time = %"
gst-plugins-ugly-0.10.6-dvdread.patch:
--- NEW FILE gst-plugins-ugly-0.10.6-dvdread.patch ---